@@ -115,11 +115,11 @@ Class GroupPages extends JTable
 
 		if ($active) 
 		{
-			$sql = "SELECT * FROM $this->_tbl WHERE gid=" . $this->_db->Quote($gid) . " AND active=1 ORDER BY porder ASC";
+			$sql = "SELECT * FROM $this->_tbl WHERE gid='$gid' AND active=1 ORDER BY porder ASC";
 		}
 		else 
 		{
-			$sql = "SELECT * FROM $this->_tbl WHERE gid=" . $this->_db->Quote($gid) . " ORDER BY porder ASC";
+			$sql = "SELECT * FROM $this->_tbl WHERE gid='$gid' ORDER BY porder ASC";
 		}
 
 		$this->_db->setQuery($sql);
@@ -152,7 +152,7 @@ Class GroupPages extends JTable
 	 */
 	public function getHighestPageOrder($gid)
 	{
-		$sql = "SELECT porder from $this->_tbl WHERE gid=" . $this->_db->Quote($gid) . " ORDER BY porder DESC LIMIT 1";
+		$sql = "SELECT porder from $this->_tbl WHERE gid='$gid' ORDER BY porder DESC LIMIT 1";
 		$this->_db->setQuery($sql);
 		return $this->_db->loadResult();
 	}
@@ -176,7 +176,7 @@ Class GroupPages extends JTable
 		$overview_access = Hubzero_Group_Helper::getPluginAccess($this->group, 'overview');
 
 		//get group discoverability
-		$discoverability = $this->group->get('discoverability');
+		$discoverability = $this->group->get('privacy');
 
 		//get the group members
 		$members = $this->group->get('members');
@@ -232,7 +232,7 @@ Class GroupPages extends JTable
 			if (($privacy == 'registered' && $this->juser->get('guest')) || ($privacy == 'members' && !in_array($this->juser->get('id'), $members))) 
 			{
 				$pContent = '';
-				$page = '<p class="info">You currently don\'t have the permissions to access this group page.</p>';
+				$page = '<p class="info">You currently dont have the permissions to access this group page.</p>';
 			} 
 			else 
 			{
@@ -337,7 +337,7 @@ Class GroupPages extends JTable
 		$isMember = ($this->authorized == 'manager' || $this->authorized == 'member') ? true : false;
  
 		$about  = '<div class="group-content-header">';
-			$about .= '<h3>' . JText::_('COM_GROUPS_OVERVIEW_ABOUT_HEADING') . '</h3>';
+			$about .= '<h3>' . JText::_('GROUPS_ABOUT_HEADING') . '</h3>';
 
 		if ($isMember && $this->group->get('private_desc') != '') 
 		{
@@ -370,9 +370,9 @@ Class GroupPages extends JTable
 		else 
 		{
 			$member_browser  = '<div class="group-content-header">';
-				$member_browser .= '<h3>' . JText::_('COM_GROUPS_OVERVIEW_MEMBERS_HEADING') . '</h3>';
+				$member_browser .= '<h3>' . JText::_('GROUPS_GROUP_MEMBERS') . '</h3>';
 				$member_browser .= '<div class="group-content-header-extra">';
-					$member_browser .= '<a href="' . JRoute::_('index.php?option=com_groups&cn=' . $this->group->get('cn') . '&active=members') . '">' . JText::_('COM_GROUPS_OVERVIEW_MEMBERS_BTN_TEXT') . ' &rarr;</a>';
+					$member_browser .= '<a href="' . JRoute::_('index.php?option=com_groups&gid=' . $this->group->get('cn') . '&active=members') . '">' . JText::_('VIEW_ALL_MEMBERS') . ' &rarr;</a>';
 				$member_browser .= '</div>';
 			$member_browser .= '</div>';
 
@@ -405,25 +405,6 @@ Class GroupPages extends JTable
 
 	 	return $about.$member_browser;
 	}
-	
-	/**
-	 * Get page content by ID
-	 * 
-	 * @return     string HTML
-	 */
-	public function getPageContent($id)
-	{
-		$sql = "SELECT title, content FROM $this->_tbl WHERE id =" . $this->_db->Quote($id);
-		$this->_db->setQuery($sql);
-		
-		$this->_db->query();
-		
-		if ($this->_db->getNumRows())
-		{
-			return($this->_db->loadObject());	
-		}
-		return false;
-	}
 
 	/**
 	 * Record a page hit
@@ -479,7 +460,7 @@ Class GroupPages extends JTable
 		//paths to thumbs thumb1 is preferred
 		$thumb1 = $path . 'thumb.png';
 		$thumb2 = $path . $name . '.' . $ext;
-		
+
 		//return profile thumb based on existence
 		if (file_exists(JPATH_ROOT . DS . $thumb1))
 		{
@@ -492,9 +473,10 @@ Class GroupPages extends JTable
 		else
 		{
 			$full = JPATH_ROOT . DS . $path . $picture;
-			
-			if (file_exists($full) && in_array($ext,  array('png', 'jpe', 'jpeg', 'jpg', 'gif')))
+			if (file_exists($full))
 			{
+				echo $user->get('uidNumber') .'<br />';
+				echo $full .'<br />';
 				ximport('Hubzero_Image');
 				$hi = new Hubzero_Image($full);
 				$hi->resize(50, false, true, true);
