@@ -47,6 +47,10 @@ class WikiControllerPage extends Hubzero_Controller
 	public function __construct($config=array())
 	{
 		$this->_base_path = JPATH_ROOT . DS . 'components' . DS . 'com_wiki';
+		if (isset($config['base_path'])) 
+		{
+			$this->_base_path = $config['base_path'];
+		}
 
 		$this->_sub = false;
 		if (isset($config['sub'])) 
@@ -87,11 +91,15 @@ class WikiControllerPage extends Hubzero_Controller
 		$wp = new WikiPage($this->database);
 		if (!$wp->count()) 
 		{
+			include_once(JPATH_ROOT . DS . 'components' . DS . 'com_wiki' . DS . 'helpers' . DS . 'setup.php');
+
 			$result = WikiSetup::initialize($this->_option);
 			if ($result) 
 			{
 				$this->setError($result);
 			}
+
+			JDEBUG ? JProfiler::getInstance('Application')->mark('afterWikiSetup') : null;
 		}
 
 		if (!is_object($this->page))
@@ -153,11 +161,24 @@ class WikiControllerPage extends Hubzero_Controller
 			);
 		}
 
-		// Does a page exist for the given pagename?
-		if (!$this->page->exist()) 
+		// Is this a special page?
+		if (strtolower($this->page->getNamespace()) == 'special') 
 		{
-			// No! Ask if they want to create a new page
-			$this->view->setLayout('doesnotexist');
+			// Set the layout
+			$this->view->setLayout('special');
+			$this->view->layout = $this->page->stripNamespace();
+			$this->view->page->scope = trim(JRequest::getVar('scope', ''));
+			$this->view->message = $this->_message;
+
+			// Ensure the special page exists
+			if (!in_array(strtolower($this->view->layout), $this->_getSpecialPages()))
+			{
+				//JError::raiseWarning(404, JText::_('WIKI_WARNING_NOT_FOUND'));
+				$this->setRedirect(
+					JRoute::_('index.php?option=' . $this->_option . '&scope=' . $this->view->page->scope)
+				);
+				return;
+			}
 
 			if ($this->getError()) 
 			{
@@ -169,7 +190,29 @@ class WikiControllerPage extends Hubzero_Controller
 			$this->view->display();
 			return;
 		}
-		
+
+		// Does a page exist for the given pagename?
+		if (!$this->page->exist()) 
+		{
+			// No! Ask if they want to create a new page
+			$this->view->setLayout('doesnotexist');
+			if ($this->_group)
+			{
+				$this->page->group_cn = $this->_group;
+				$this->page->scope = $this->_group . '/wiki';
+			}
+
+			if ($this->getError()) 
+			{
+				foreach ($this->getErrors() as $error)
+				{
+					$this->view->setError($error);
+				}
+			}
+			$this->view->display();
+			return;
+		}
+
 		if ($this->page->group_cn && !$this->_group)
 		{
 			$this->setRedirect(
@@ -194,8 +237,7 @@ class WikiControllerPage extends Hubzero_Controller
 				$bit = trim($bit);
 				if ($bit != '/' && $bit != '') 
 				{
-					$p = new WikiPage($this->database);
-					$p->load($bit, implode('/', $s));
+					$p = WikiPage::getInstance($bit, implode('/', $s));
 					if ($p->id) 
 					{
 						$pathway->addItem($p->title, 'index.php?option=' . $this->_option . '&scope=' . $p->scope . '&pagename=' . $p->pagename);
@@ -204,6 +246,14 @@ class WikiControllerPage extends Hubzero_Controller
 				}
 			}
 		}
+		if ($this->page->group_cn)
+		{
+			$pathway->addItem(
+				JText::_('Wiki'),
+				'index.php?option=' . $this->_option . '&scope=' . $this->page->scope
+			);
+		}
+
 		$pathway->addItem(
 			$this->view->title,
 			'index.php?option=' . $this->_option . '&scope=' . $this->page->scope . '&pagename=' . $this->page->pagename
@@ -245,23 +295,38 @@ class WikiControllerPage extends Hubzero_Controller
 		$p =& Hubzero_Wiki_Parser::getInstance();
 
 		// Parse the text
-		$this->view->revision->pagehtml = $p->parse($this->view->revision->pagetext, $wikiconfig, true, true);
+		if (intval($this->config->get('cache', 1)))
+		{
+			// Caching
+			// Default time is 15 minutes
+			$cache =& JFactory::getCache('callback');
+			$cache->setCaching(1);
+			$cache->setLifeTime(intval($this->config->get('cache_time', 15)));
 
-		// Create a linked Table of Contents
-		//$this->view->output = (is_object($p->_parser)) ? $p->_parser->parser->formatHeadings($this->view->revision->pagehtml) : array('text'=>$this->view->revision->pagehtml,'toc'=>'');
+			$this->view->revision->pagehtml = $cache->call(
+				array($p, 'parse'), 
+				$this->view->revision->pagetext, $wikiconfig, true, true
+			);
+		}
+		else 
+		{
+			$this->view->revision->pagehtml = $p->parse($this->view->revision->pagetext, $wikiconfig, true, true);
+		}
+
+		JDEBUG ? JProfiler::getInstance('Application')->mark('afterWikiParse') : null;
 
 		// Get the page's tags
-		if ($this->config->get('admin')) 
+		/*if ($this->config->get('admin')) 
 		{
 			$this->view->tags = $this->page->getTags(1);
 		} 
 		else 
 		{
 			$this->view->tags = $this->page->getTags();
-		}
+		}*/
 
 		$this->view->message = $this->_message;
-		
+
 		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
@@ -273,6 +338,49 @@ class WikiControllerPage extends Hubzero_Controller
 		$this->view->display();
 	}
 
+	/**
+	 * Get a list of special pages
+	 * 
+	 * @return     array
+	 */
+	protected function _getSpecialPages()
+	{
+		$path = JPATH_ROOT . DS . 'components' . DS . 'com_wiki' . DS . 'views' . DS . 'special' . DS . 'tmpl';
+
+		$pages = array();
+
+		if (is_dir($path))
+		{
+			jimport('joomla.filesystem.file');
+			// Loop through all files and separate them into arrays of images, folders, and other
+			$dirIterator = new DirectoryIterator($path);
+			foreach ($dirIterator as $file)
+			{
+				if ($file->isDot() || $file->isDir())
+				{
+					continue;
+				}
+
+				if ($file->isFile())
+				{
+					$name = $file->getFilename();
+					if (JFile::getExt($name) != 'php'
+					 || 'cvs' == strtolower($name)
+					 || '.svn' == strtolower($name))
+					{
+						continue;
+					}
+
+					$pages[] = strtolower(JFile::stripExt($name));
+				}
+			}
+
+			sort($pages);
+		}
+
+		return $pages;
+	}
+
 	/**
 	 * Show a form for creating an entry
 	 * 
@@ -561,7 +669,7 @@ class WikiControllerPage extends Hubzero_Controller
 			);
 			return;
 		}
-		
+
 		// Incoming revision
 		$rev = JRequest::getVar('revision', array(), 'post', 'none', 2);
 		$rev['pageid'] = (isset($rev['pageid'])) ? intval($rev['pageid']) : 0;
