@@ -2,18 +2,6 @@
 
 class Hubzero_Ldap
 {
-	private static $errors  = array(
-		'errors'   => true,
-		'fatal'    => array(),
-		'warnings' => array()
-		);
-	private static $success = array(
-		'success'  => true,
-		'added'    => 0,
-		'deleted'  => 0,
-		'modified' => 0
-		);
-
 	public static function getLDO($debug = 0)
 	{
 		static $conn = false;
@@ -167,7 +155,6 @@ class Hubzero_Ldap
 	
 		if (empty($db))
 		{
-			self::$errors['fatal'][] = 'Error connecting to the database';
 			return false;
 		}
 		
@@ -175,10 +162,9 @@ class Hubzero_Ldap
 	
 		if (empty($conn))
 		{
-			self::$errors['fatal'][] = 'LDAP connection failed';
 			return false;
 		}
-
+		
 		$query = "SELECT u.id AS uidNumber, u.username AS uid, u.name AS cn, " .
 				" p.gidNumber, p.homeDirectory, p.loginShell, " .
 				" pwd.passhash AS userPassword, pwd.shadowLastChange, pwd.shadowMin, pwd.shadowMax, pwd.shadowWarning, " .
@@ -195,15 +181,9 @@ class Hubzero_Ldap
 		{
 			$query .= " WHERE u.username = " . $db->Quote($user) . " LIMIT 1;";
 		}
-
+	
 		$db->setQuery($query);
 		$dbinfo = $db->loadAssoc();
-
-		// Don't sync usernames that are negative numbers (these are auth_link temp accounts)
-		if(is_numeric($dbinfo['uid']) && $dbinfo['uid'] <= 0)
-		{
-			return false;
-		}
 		
 		if (!empty($dbinfo))
 		{
@@ -259,28 +239,15 @@ class Hubzero_Ldap
 
 			if (empty($entry['uid']) || empty($entry['cn']) || empty($entry['gidNumber']))
 			{
-				self::$errors['warning'][] = "User {$dbinfo['uid']} missing one of uid, cn, or gidNumber";
 				return false;
 			}
 				
 			if (empty($entry['homeDirectory']) || empty($entry['uidNumber']))
 			{
-				self::$errors['warning'][] = "User {$dbinfo['uid']} missing one of homeDirectory or uidNumber";
 				return false;
 			}
 			
-			$result = @ldap_add($conn, $dn, $entry);
-
-			if($result !== true)
-			{
-				self::$errors['warning'][] = @ldap_error($conn);
-				return false;
-			}
-			else
-			{
-				++self::$success['added'];
-				return true;
-			}
+			return @ldap_add($conn, $dn, $entry);
 		}
 	
 		$ldapinfo = null;
@@ -329,18 +296,7 @@ class Hubzero_Ldap
 		{
 			$dn = "uid=" . $ldapinfo['uid'] . ",ou=users," . $hubLDAPBaseDN;
 	
-			$result = @ldap_delete($conn, $dn);
-
-			if($result !== true)
-			{
-				self::$errors['warning'][] = @ldap_error($conn);
-				return false;
-			}
-			else
-			{
-				++self::$success['deleted'];
-				return true;
-			}
+			return @ldap_delete($conn, $dn);
 		}
 	
 		/* Otherwise update the ldap entry */
@@ -364,18 +320,7 @@ class Hubzero_Ldap
 	
 		$dn = "uid=" . $ldapinfo['uid'] . ",ou=users," . $hubLDAPBaseDN;
 		
-		$result = @ldap_modify($conn, $dn, $entry);
-
-		if($result !== true)
-		{
-			self::$errors['warning'][] = @ldap_error($conn);
-			return false;
-		}
-		else
-		{
-			++self::$success['modified'];
-			return true;
-		}
+		return @ldap_modify($conn, $dn, $entry);
 	}
 	
 	static function syncGroup($group)
@@ -384,7 +329,6 @@ class Hubzero_Ldap
 	
 		if (empty($db))
 		{
-			self::$errors['fatal'][] = 'Error connecting to the database';
 			return false;
 		}
 	
@@ -392,7 +336,6 @@ class Hubzero_Ldap
 	
 		if (empty($conn))
 		{
-			self::$errors['fatal'][] = 'LDAP connection failed';
 			return false;
 		}
 	
@@ -459,18 +402,7 @@ class Hubzero_Ldap
 				}
 			}
 
-			$result = @ldap_add($conn, $dn, $entry);
-
-			if($result !== true)
-			{
-				self::$errors['warning'][] = @ldap_error($conn);
-				return false;
-			}
-			else
-			{
-				++self::$success['added'];
-				return true;
-			}
+			return @ldap_add($conn, $dn, $entry);
 		}
 
 		$ldapinfo = null;
@@ -521,18 +453,7 @@ class Hubzero_Ldap
 		{
 			$dn = "cn=" . $ldapinfo['cn'] . ",ou=groups," . $hubLDAPBaseDN;
 
-			$result = @ldap_delete($conn, $dn);
-
-			if($result !== true)
-			{
-				self::$errors['warning'][] = @ldap_error($conn);
-				return false;
-			}
-			else
-			{
-				++self::$success['deleted'];
-				return true;
-			}
+			return @ldap_delete($conn, $dn);
 		}
 
 		/* Otherwise update the ldap entry */
@@ -554,18 +475,7 @@ class Hubzero_Ldap
 			}
 		}
 
-		$result = @ldap_modify($conn, $dn, $entry);
-
-		if($result !== true)
-		{
-			self::$errors['warning'][] = @ldap_error($conn);
-			return false;
-		}
-		else
-		{
-			++self::$success['modified'];
-			return true;
-		}
+		return @ldap_modify($conn, $dn, $entry);
 	}
 	
 	static function addGroupMemberships($group, $members)
@@ -734,27 +644,12 @@ class Hubzero_Ldap
 		{
 			return false;
 		}
-
-		foreach($result as $row)
+	
+		foreach($result as $row) 
 		{
-			self::syncGroup($row);
-
-			if(is_array(self::$errors['fatal']) && !empty(self::$errors['fatal'][0]))
-			{
-				// If there's a fatal error, go ahead and stop
-				return self::$errors;
-			}
+			self::syncGroup($row);	
 		}
-
-		if(!empty(self::$errors['fatal'][0]) || !empty(self::$errors['warning'][0]))
-		{
-			return self::$errors;
-		}
-		else
-		{
-			return self::$success;
-		}
-	}
+	}				
 
 	/**
 	 * Short description for 'syncAllGroups'
@@ -783,21 +678,6 @@ class Hubzero_Ldap
 		foreach($result as $row)
 		{
 			self::syncUser($row);
-
-			if(is_array(self::$errors['fatal']) && !empty(self::$errors['fatal'][0]))
-			{
-				// If there's a fatal error, go ahead and stop
-				return self::$errors;
-			}
-		}
-
-		if(!empty(self::$errors['fatal'][0]) || !empty(self::$errors['warning'][0]))
-		{
-			return self::$errors;
-		}
-		else
-		{
-			return self::$success;
 		}
 	}
 	
@@ -807,8 +687,7 @@ class Hubzero_Ldap
 	    
 	    if (empty($conn))
 	    {
-			self::$errors['fatal'][] = 'LDAP connection failed';
-			return self::$errors;
+	    	return false;
 	    }
 	    
 	    /* delete all old hubGroup schema based group entries */
@@ -849,16 +728,7 @@ class Hubzero_Ldap
         
         foreach($gids as $giddn)
         {
-			$result = @ldap_delete($conn, $giddn);
-
-			if($result !== true)
-			{
-				self::$errors['warning'][] = @ldap_error($conn);
-			}
-			else
-			{
-				++self::$success['deleted'];
-			}
+        	@ldap_delete($conn, $giddn);
         }
         
         /* delete all entries that have mysql counterparts */
@@ -881,16 +751,7 @@ class Hubzero_Ldap
         foreach($result as $row)
         {
         	$dn = "cn=$row," .  "ou=groups," . $hubLDAPBaseDN;
-			$result = @ldap_delete($conn, $dn);
-
-			if($result !== true)
-			{
-				self::$errors['warning'][] = @ldap_error($conn);
-			}
-			else
-			{
-				++self::$success['deleted'];
-			}
+        	@ldap_delete($conn, $dn);
         }
         
         /* delete any remaining items with gid > 1000 */
@@ -922,26 +783,10 @@ class Hubzero_Ldap
         foreach($gids as $gid)
         {
         	$dn = "gid=$gid," . "ou=groups," . $hubLDAPBaseDN;
-			$result = @ldap_delete($conn, $dn);
-
-			if($result !== true)
-			{
-				self::$errors['warning'][] = @ldap_error($conn);
-			}
-			else
-			{
-				++self::$success['deleted'];
-			}
-		}
-
-		if(!empty(self::$errors['fatal'][0]) || !empty(self::$errors['warning'][0]))
-		{
-			return self::$errors;
-		}
-		else
-		{
-			return self::$success;
-		}
+        	@ldap_delete($conn, $dn);
+        }
+        
+        return true;
    	}
 	
 	public static function deleteAllUsers()
@@ -950,8 +795,7 @@ class Hubzero_Ldap
 	    
 	    if (empty($conn))
 	    {
-			self::$errors['fatal'][] = 'LDAP connection failed';
-			return self::$errors;
+	    	return false;
 	    }
 	    
 	    /* delete all old hubAccount schema based user entries */
@@ -986,16 +830,7 @@ class Hubzero_Ldap
         foreach($uids as $uid)
         {
         	$dn = "uid=$uid," . "ou=users," . $hubLDAPBaseDN;
-			$result = @ldap_delete($conn, $dn);
-
-			if($result !== true)
-			{
-				self::$errors['warning'][] = @ldap_error($conn);
-			}
-			else
-			{
-				++self::$success['deleted'];
-			}
+        	@ldap_delete($conn, $dn);
         }
         
         /* delete all entries that have mysql counterparts */
@@ -1018,16 +853,7 @@ class Hubzero_Ldap
         foreach($result as $row)
         {
         	$dn = "uid=$row," .  "ou=users," . $hubLDAPBaseDN;
-			$result = @ldap_delete($conn, $dn);
-
-			if($result !== true)
-			{
-				self::$errors['warning'][] = @ldap_error($conn);
-			}
-			else
-			{
-				++self::$success['deleted'];
-			}
+        	@ldap_delete($conn, $dn);
         }
         
         /* delete any remaining items with gid > 1000 */
@@ -1059,25 +885,7 @@ class Hubzero_Ldap
         foreach($uids as $uid)
         {
         	$dn = "uid=$uid," . "ou=users," . $hubLDAPBaseDN;
-			$result = @ldap_delete($conn, $dn);
-
-			if($result !== true)
-			{
-				self::$errors['warning'][] = @ldap_error($conn);
-			}
-			else
-			{
-				++self::$success['deleted'];
-			}
+        	@ldap_delete($conn, $dn);
         }
-
-		if(!empty(self::$errors['fatal'][0]) || !empty(self::$errors['warning'][0]))
-		{
-			return self::$errors;
-		}
-		else
-		{
-			return self::$success;
-		}
 	}
 }
\ No newline at end of file
