@@ -31,11 +31,11 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die( 'Restricted access' );
 
-if ($this->getError())
+if ($this->error)
 {
 ?>
-	<p class="error"><?php echo $this->getError(); ?></p>
-<?php
+	<p class="error"><?php echo $this->error; ?></p>
+<?php 
 }
 else
 {
