@@ -31,21 +31,30 @@
 // Check to ensure this file is included in Joomla!
 defined('_JEXEC') or die('Restricted access');
 
+jimport('joomla.plugin.plugin');
+
 /**
  * Groups Plugin class for messages
  */
-class plgGroupsMessages extends \Hubzero\Plugin\Plugin
+class plgGroupsMessages extends JPlugin
 {
 	/**
-	 * Affects constructor behavior. If true, language files will be loaded automatically.
-	 *
-	 * @var    boolean
+	 * Constructor
+	 * 
+	 * @param      object &$subject Event observer
+	 * @param      array  $config   Optional config values
+	 * @return     void
 	 */
-	protected $_autoloadLanguage = true;
+	public function __construct(&$subject, $config)
+	{
+		parent::__construct($subject, $config);
+
+		$this->loadLanguage();
+	}
 
 	/**
 	 * Return the alias and name for this category of content
-	 *
+	 * 
 	 * @return     array
 	 */
 	public function &onGroupAreas()
@@ -54,15 +63,14 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 			'name' => 'messages',
 			'title' => JText::_('PLG_GROUPS_MESSAGES'),
 			'default_access' => $this->params->get('plugin_access','members'),
-			'display_menu_tab' => $this->params->get('display_tab', 1),
-			'icon' => '2709'
+			'display_menu_tab' => true
 		);
 		return $area;
 	}
 
 	/**
 	 * Return data on a group view (this will be some form of HTML)
-	 *
+	 * 
 	 * @param      object  $group      Current group
 	 * @param      string  $option     Name of the component
 	 * @param      string  $authorized User's authorization level
@@ -87,22 +95,22 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 		$this_area = $this->onGroupAreas();
 
 		// Check if our area is in the array of areas we want to return results for
-		if (is_array($areas) && $limit)
+		if (is_array($areas) && $limit) 
 		{
-			if (!in_array($this_area['name'], $areas))
+			if (!in_array($this_area['name'], $areas)) 
 			{
-				return $arr;
+				return;
 			}
 		}
 
 		// Are we returning HTML?
-		if ($return == 'html')
+		if ($return == 'html') 
 		{
 			//get group members plugin access level
 			$group_plugin_acl = $access[$active];
 
 			//Create user object
-			$juser = JFactory::getUser();
+			$juser =& JFactory::getUser();
 
 			//get the group members
 			$members = $group->get('members');
@@ -116,38 +124,38 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 			$this->action = $action;
 
 			//if set to nobody make sure cant access
-			if ($group_plugin_acl == 'nobody')
+			if ($group_plugin_acl == 'nobody') 
 			{
 				$arr['html'] = '<p class="info">' . JText::sprintf('GROUPS_PLUGIN_OFF', ucfirst($active)) . '</p>';
 				return $arr;
 			}
 
 			//check if guest and force login if plugin access is registered or members
-			if ($juser->get('guest')
-			 && ($group_plugin_acl == 'registered' || $group_plugin_acl == 'members'))
+			if ($juser->get('guest') 
+			 && ($group_plugin_acl == 'registered' || $group_plugin_acl == 'members')) 
 			{
-				$url = JRoute::_('index.php?option=com_groups&cn=' . $group->get('cn') . '&active=' . $active, false, true);
-
-				$this->redirect(
-					JRoute::_('index.php?option=com_users&view=login&return=' . base64_encode($url)),
-					JText::sprintf('GROUPS_PLUGIN_REGISTERED', ucfirst($active)),
-					'warning'
-				);
-				return;
+				ximport('Hubzero_Module_Helper');
+				$arr['html']  = '<p class="info">' . JText::sprintf('GROUPS_PLUGIN_REGISTERED', ucfirst($active)) . '</p>';
+				$arr['html'] .= Hubzero_Module_Helper::renderModules('force_mod');
+				return $arr;
 			}
 
 			//check to see if user is member and plugin access requires members
-			if (!in_array($juser->get('id'), $members)
-			 && $group_plugin_acl == 'members'
-			 && $authorized != 'admin')
+			if (!in_array($juser->get('id'), $members) 
+			 && $group_plugin_acl == 'members' 
+			 && $authorized != 'admin') 
 			{
 				$arr['html'] = '<p class="info">' . JText::sprintf('GROUPS_PLUGIN_REQUIRES_MEMBER', ucfirst($active)) . '</p>';
 				return $arr;
 			}
 
 			//push styles to the view
-			\Hubzero\Document\Assets::addPluginStylesheet('groups','messages');
-			\Hubzero\Document\Assets::addPluginScript('groups','messages');
+			ximport('Hubzero_Document');
+			Hubzero_Document::addPluginStylesheet('groups','messages');
+            Hubzero_Document::addPluginScript('groups','messages');
+
+			// Load some needed libraries
+			ximport('Hubzero_Message');
 
 			$task = strtolower(trim($action));
 
@@ -167,13 +175,13 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Show sent messages
-	 *
+	 * 
 	 * @return     string
 	 */
 	protected function _sent()
 	{
 		// Set the page title
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle(JText::_(strtoupper($this->_name)) . ': ' . $this->group->get('description') . ': ' . JText::_('PLG_GROUPS_MESSAGES_SENT'));
 
 		// Filters for returning results
@@ -183,8 +191,8 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 		$filters['group_id'] = $this->group->get('gidNumber');
 
 		// Instantiate our message object
-		$database = JFactory::getDBO();
-		$recipient = new \Hubzero\Message\Message($database);
+		$database =& JFactory::getDBO();
+		$recipient = new Hubzero_Message_Message($database);
 
 		// Retrieve data
 		$total = $recipient->getSentMessagesCount($filters);
@@ -194,13 +202,14 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 		// Initiate paging
 		jimport('joomla.html.pagination');
 		$pageNav = new JPagination(
-			$total,
-			$filters['start'],
+			$total, 
+			$filters['start'], 
 			$filters['limit']
 		);
 
 		// Instantiate a view
-		$view = new \Hubzero\Plugin\View(
+		ximport('Hubzero_Plugin_View');
+		$view = new Hubzero_Plugin_View(
 			array(
 				'folder'  => 'groups',
 				'element' => 'messages',
@@ -214,7 +223,7 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 		$view->authorized = $this->authorized;
 		$view->rows = $rows;
 		$view->pageNav = $pageNav;
-		if ($this->getError())
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -228,7 +237,7 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Show a message
-	 *
+	 * 
 	 * @return     string
 	 */
 	protected function _view()
@@ -237,16 +246,16 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 		$message = JRequest::getVar('msg','','get');
 
 		//if there is no message id show all sent messages
-		if (!$message)
+		if (!$message) 
 		{
 			return $this->_sent();
 		}
 
 		//insantiate db
-		$database = JFactory::getDBO();
+		$database =& JFactory::getDBO();
 
 		// Load the message and parse it
-		$xmessage = new \Hubzero\Message\Message($database);
+		$xmessage = new Hubzero_Message_Message($database);
 		$xmessage->load($message);
 		$xmessage->message = stripslashes($xmessage->message);
 		$xmessage->message = str_replace("\n", "\n ", $xmessage->message);
@@ -254,13 +263,14 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 		$xmessage->message = nl2br($xmessage->message);
 		$xmessage->message = str_replace("\t", '&nbsp;&nbsp;&nbsp;&nbsp;', $xmessage->message);
 
-		if (substr($xmessage->component, 0, 4) == 'com_')
+		if (substr($xmessage->component, 0, 4) == 'com_') 
 		{
 			$xmessage->component = substr($xmessage->component, 4);
 		}
 
 		// Instantiate the view
-		$view = new \Hubzero\Plugin\View(
+		ximport('Hubzero_Plugin_View');
+		$view = new Hubzero_Plugin_View(
 			array(
 				'folder'  => 'groups',
 				'element' => 'messages',
@@ -274,7 +284,7 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 		$view->authorized = $this->authorized;
 		$view->xmessage = $xmessage;
 		$view->no_html = JRequest::getInt('no_html', 0);
-		if ($this->getError())
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -288,23 +298,24 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Show a form for creating a message
-	 *
+	 * 
 	 * @return     string
 	 */
 	protected function _create()
 	{
 		// Ensure only admins and group managers can create messages
-		if ($this->authorized != 'manager' && $this->authorized != 'admin')
+		if ($this->authorized != 'manager' && $this->authorized != 'admin') 
 		{
 			return false;
 		}
 
 		// Set the page title
-		$document = JFactory::getDocument();
+		$document =& JFactory::getDocument();
 		$document->setTitle(JText::_(strtoupper($this->_name)).': '.$this->group->get('description').': '.JText::_('PLG_GROUPS_MESSAGES_SEND'));
 
 		// Instantiate a vew
-		$view = new \Hubzero\Plugin\View(
+		ximport('Hubzero_Plugin_View');
+		$view = new Hubzero_Plugin_View(
 			array(
 				'folder'  => 'groups',
 				'element' => 'messages',
@@ -313,8 +324,8 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 		);
 
 		//get all member roles
-		$db = JFactory::getDBO();
-		$sql = "SELECT * FROM #__xgroups_roles WHERE gidNumber=".$db->quote($this->group->get('gidNumber'));
+		$db =& JFactory::getDBO();
+		$sql = "SELECT * FROM #__xgroups_roles WHERE gidNumber='".$this->group->get('gidNumber')."'";
 		$db->setQuery($sql);
 		$member_roles = $db->loadAssocList();
 
@@ -331,7 +342,7 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 		$view->members = $members;
 		$view->users = JRequest::getVar('users', array('all'));
 		$view->no_html = JRequest::getInt('no_html', 0);
-		if ($this->getError())
+		if ($this->getError()) 
 		{
 			foreach ($this->getErrors() as $error)
 			{
@@ -345,21 +356,18 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Send a message
-	 *
+	 * 
 	 * @return     mixed
 	 */
 	protected function _send()
 	{
 		// Ensure the user is logged in
-		$juser = JFactory::getUser();
-		if ($juser->get('guest'))
+		$juser =& JFactory::getUser();
+		if ($juser->get('guest')) 
 		{
 			return false;
 		}
 
-		//message
-		$message = JText::sprintf('PLG_GROUPS_MESSAGES_FROM_GROUP', $this->group->get('cn'));
-
 		// Incoming array of users to message
 		$mbrs = JRequest::getVar('users', array(0), 'post');
 		switch ($mbrs[0])
@@ -385,26 +393,24 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 				$group_id = $this->group->get('gidNumber');
 			break;
 			default:
-				$message = JText::sprintf('PLG_GROUPS_MESSAGES_FOR_GROUP_MEMBER', $this->group->get('cn'));
-
-				foreach ($mbrs as $mbr)
+				foreach ($mbrs as $mbr) 
 				{
-					if (strstr($mbr, '_'))
+					if (strstr($mbr, '_')) 
 					{
 						$role = explode('_', $mbr);
-						$db = JFactory::getDBO();
-						$sql = "SELECT uidNumber FROM #__xgroups_member_roles WHERE roleid=" . $db->Quote($role[1]);
+						$db =& JFactory::getDBO();
+						$sql = "SELECT uidNumber FROM #__xgroups_member_roles WHERE role='".$role[1]."'";
 						$db->setQuery($sql);
 						$member_roles = $db->loadAssocList();
-						foreach ($member_roles as $member)
+						foreach ($member_roles as $member) 
 						{
 							$members[] = $member['uidNumber'];
 						}
 						$mbrs = $members;
 						$action = 'group_role_message';
 						$group_id = $this->group->get('gidNumber');
-					}
-					else
+					} 
+					else 
 					{
 						$action = '';
 						$group_id = 0;
@@ -415,108 +421,66 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 		}
 
 		// Incoming message and subject
-		$s = JRequest::getVar('subject', JText::_('PLG_GROUPS_MESSAGES_SUBJECT'));
-		$m = JRequest::getVar('message', '');
+		$subject = JRequest::getVar('subject', JText::_('PLG_GROUPS_MESSAGES_SUBJECT'));
+		$message = JRequest::getVar('message', '');
 
 		// Ensure we have a message
-		if (!$s || !$m)
+		if (!$subject || !$message) 
 		{
 			$html  = '<p class="error">You must enter all required fields</p>';
 			$html .= $this->_create();
 			return $html;
 		}
 
-		// get all group members
-		$recipients = array();
-		foreach ($mbrs as $mbr)
-		{
-			if ($profile = \Hubzero\User\Profile::getInstance($mbr))
-			{
-				$recipients[$profile->get('email')] = $profile->get('name');
-			}
-		}
-
-		// add invite emails if sending to invitees
-		if ($action == 'group_invitees_message')
-		{
-			// Get invite emails
-			$db = JFactory::getDBO();
-			$group_inviteemails = new \Hubzero\User\Group\InviteEmail($db);
-			$current_inviteemails = $group_inviteemails->getInviteEmails($this->group->get('gidNumber'), true);
-
-			foreach ($current_inviteemails as $current_inviteemail)
-			{
-				$recipients[$current_inviteemail] = $current_inviteemail;
-			}
-		}
-
-		// define from details
-		$config = JFactory::getConfig();
-		$from = array(
-			'name'  => $this->group->get('description') . " Group on " . $config->getValue("fromname"),
-			'email' => $config->getValue("mailfrom")
-		);
-
-		// create url
-		$juri = JURI::getInstance();
-		$sef = JRoute::_('index.php?option='.$this->_option.'&cn='. $this->group->get('cn'));
+		// Add a link to the group page to the bottom of the message
+		$juri =& JURI::getInstance();
+		$sef = JRoute::_('index.php?option='.$this->_option.'&gid='. $this->group->get('cn'));
 		$sef = ltrim($sef, DS);
 
-		// create subject
-		$subject = $s . " [Email sent on Behalf of " . $juser->get('name') . "]";
+		$message .= "\r\n\r\n------------------------------------------------\r\n". $juri->base().$sef . "\r\n";
 
-		//message
-		$plain  = JText::sprintf('PLG_GROUPS_MESSAGES_FROM_GROUP', $this->group->get('cn'));
-		$plain .= "\r\n------------------------------------------------\r\n\r\n";
-		$plain .= $m;
-
-		// create message
-		$plain .= "\r\n\r\n------------------------------------------------\r\n". $juri->base().$sef . "\r\n";
-
-		// create message object
-		$message = new \Hubzero\Mail\Message();
-
-		// set message details and send
-		$message->setSubject($subject)
-				->addFrom($from['email'], $from['name'])
-				->setTo($recipients)
-				->addPart($plain, 'text/plain')
-				->send();
-
-		// add invite emails if sending to invitees
-		if ($action == 'group_invitees_message')
+		// Build the "from" data for the e-mail
+		$from = array();
+		$config =& JFactory::getConfig();
+		$from['name'] = $this->group->get('description') . " Group on " . $config->getValue("fromname");
+		$from['email'] = $config->getValue("mailfrom");
+		
+		//append "on behalf..." to subject
+		$subject .= " - Email sent on Behalf of " . $juser->get('name');
+		
+		// Send the message
+		JPluginHelper::importPlugin('xmessage');
+		$dispatcher =& JDispatcher::getInstance();
+		if (!$dispatcher->trigger('onSendMessage', array('group_message', $subject, $message, $from, $mbrs, $this->_option, null, '', $group_id))) 
 		{
-			// Get invite emails
-			$db = JFactory::getDBO();
-			$group_inviteemails = new \Hubzero\User\Group\InviteEmail($db);
-			$current_inviteemails = $group_inviteemails->getInviteEmails($this->group->get('gidNumber'), true);
-
-			$headers  = 'From: ' . $from['name'] . ' <' . $from['email'] . '>' . "\r\n";
-			$headers .= 'Reply-To: ' . $from['replytoname'] . ' <' . $from['replytoemail'] . '>' . "\r\n";
-			foreach ($current_inviteemails as $current_inviteemail)
-			{
-				mail($current_inviteemail, $subject, $message, $headers);
-			}
+			$this->setError(JText::_('GROUPS_ERROR_EMAIL_MEMBERS_FAILED'));
 		}
 
 		// Log the action
-		if ($action)
+		if ($action) 
 		{
-			// log invites
-			GroupsModelLog::log(array(
-				'gidNumber' => $this->group->get('gidNumber'),
-				'action'    => $action,
-				'comments'  => array($juser->get('id'))
-			));
+			$database =& JFactory::getDBO();
+			$log = new XGroupLog($database);
+			$log->gid = $this->group->get('gidNumber');
+			$log->timestamp = date('Y-m-d H:i:s', time());
+			$log->action = $action;
+			$log->actorid = $juser->get('id');
+			if (!$log->store()) 
+			{
+				foreach ($log->getErrors() as $error)
+				{
+					$this->setError($error);
+				}
+			}
 		}
 
 		// Determine if we're returning HTML or not
 		// (if no - this is an AJAX call)
 		$no_html = JRequest::getInt('no_html', 0);
-		if (!$no_html)
+		if (!$no_html) 
 		{
 			$html = '';
-			if ($this->getError())
+			if ($this->getError()) 
 			{
 				$html .= '<p class="error">' . $this->getError() . '</p>';
 			}
@@ -528,7 +492,7 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Auto-link mailto, ftp, and http strings in text
-	 *
+	 * 
 	 * @param      array  $matches Text to autolink
 	 * @return     string
 	 */
@@ -536,7 +500,7 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 	{
 		$href = $matches[0];
 
-		if (substr($href, 0, 1) == '!')
+		if (substr($href, 0, 1) == '!') 
 		{
 			return substr($href, 1);
 		}
@@ -546,15 +510,15 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 		$href = str_replace('&#8221', '', $href);
 
 		$h = array('h', 'm', 'f', 'g', 'n');
-		if (!in_array(substr($href,0,1), $h))
+		if (!in_array(substr($href,0,1), $h)) 
 		{
 			$href = substr($href, 1);
 		}
 		$name = trim($href);
-		if (substr($name, 0, 7) == 'mailto:')
+		if (substr($name, 0, 7) == 'mailto:') 
 		{
 			$name = substr($name, 7, strlen($name));
-			$name = self::obfuscate($name);
+			$name = plgGroupsMessages::obfuscate($name);
 
 			$href = 'mailto:' . $name;
 		}
@@ -566,11 +530,11 @@ class plgGroupsMessages extends \Hubzero\Plugin\Plugin
 
 	/**
 	 * Obfuscate an email address
-	 *
+	 * 
 	 * @param      string $email Address to obfuscate
 	 * @return     string
 	 */
-	public static function obfuscate($email)
+	public function obfuscate($email)
 	{
 		$length = strlen($email);
 		$obfuscatedEmail = '';
