@@ -139,7 +139,7 @@ WYKIWYG.converter = function() {
 					if (rel && rel[1] == 'filemacro') {
 						return '[[File(' + href[1] + (href[1] == innerHTML ? '' : ', desc="' + innerHTML + '"') + ')]]';
 					}
-					return href ? '[' + href[1] + (href[1] == innerHTML ? '' : ' ' + innerHTML) + ']' : str;
+					return href ? '[' + href[1] + ' ' + innerHTML + ']' : str;
 				}
 			},
 			{
@@ -157,10 +157,6 @@ WYKIWYG.converter = function() {
 			{
 				patterns: ['code', 'tt'],
 				replacement: function(str, attrs, innerHTML) {
-					var cls = attrs.match(attrRegExp('class'));
-					if (cls && cls[1] == 'wiki-math') {
-						return innerHTML ? '<math>' + innerHTML + '</math>' : '';
-					}
 					return innerHTML ? '`' + innerHTML + '`' : '';
 				}
 			},
@@ -313,7 +309,7 @@ WYKIWYG.converter = function() {
 							innerHTML = innerHTML.replace(/^\s+/, '');
 							innerHTML = innerHTML.replace(/\n\n/g, '\n\n		');
 							// indent nested lists
-							innerHTML = innerHTML.replace(/\n([ ]*)+(\*|#|\d+\.) /g, '\n$1 $2 ');
+							innerHTML = innerHTML.replace(/\n([ ]*)+(\*|\d+\.) /g, '\n$1		$2 ');
 							return prefix + innerHTML;
 						});
 					}
@@ -365,12 +361,8 @@ WYKIWYG.converter = function() {
 				inner = inner.replace(/^\s+|\s+$/g, '');
 				inner = inner.replace(/<tbody>/g, '');
 				inner = inner.replace(/<\/tbody>/g, '');
-				//inner = inner.replace(/<tr><t[dh]>(.+?)<\/t[dh]><\/tr>/g, '||$1||');
-				//inner = inner.replace(/<\/t[dh]><t[dh]>/g, '||');
-				inner = inner.replace(/<tr>(.+?)<\/tr>/g, '|$1|');
-				inner = inner.replace(/<\/?td>/g, '|');
-				inner = inner.replace(/<th>/g, '|=');
-				inner = inner.replace(/<\/th>/g, '=|');
+				inner = inner.replace(/<tr><td>(.+?)<\/td><\/tr>/g, '||$1||');
+				inner = inner.replace(/<\/td><td>/g, '||');
 				inner = cleanUp(inner);
 				return inner;
 			});
@@ -503,16 +495,6 @@ WYKIWYG.converter = function() {
 			return text;
 		}
 
-		function _DoMath(text) {
-			text = text.replace(/(<(math)>(.*?)<\/\2>)/g, function(wholeMatch, m1, m2, m3){
-				var tag = m2,
-					content = m3;
-
-				return '<code class="wiki-math">' + content + '</code>';
-			});
-			return text;
-		}
-
 		function hashElement(wholeMatch,m1) {
 			var blockText = m1;
 
@@ -575,7 +557,7 @@ WYKIWYG.converter = function() {
 			// Make links out of things like `http://example.com/`
 			// Must come after _DoAnchors(), otherwise declared links [http://something.com]
 			// will get converted to [<a href="http://something.com">http://something.com</a>]
-			//text = _DoAutoLinks(text);
+			text = _DoAutoLinks(text);
 			text = _EncodeAmpsAndAngles(text);
 			text = _DoItalicsAndBold(text);
 
@@ -662,7 +644,7 @@ WYKIWYG.converter = function() {
 			url = escapeCharacters(url,"*_");
 			var result = (whole_match.substr(0, 1) == ' ' ? ' ' : '') + "<a href=\"" + url + "\"";
 			
-			if (title != "" && title != url) {
+			if (title != "") {
 				title = title.replace(/"/g,"&quot;");
 				title = escapeCharacters(title,"*_");
 				result +=  " title=\"" + title + "\"";
@@ -893,8 +875,7 @@ WYKIWYG.converter = function() {
 			text += "~0";
 
 			// Re-usable pattern to match any entirel ul or ol list:
-			//var whole_list = /^(([ ]+([*\*]|[*\#]|\d\.)[ \t]+)[^\r]+?(~0|\n{2,}(?=\S)(?![ \t]*(?:[*\*]|[*\#]|\d\.)[ \t]+)))/gm;
-			var whole_list = /^(([ ]+([*#]|\d\.)[ \t]+)[^\r]+?(~0|\n{2,}(?=\S)(?![ \t]*(?:[*#]|\d\.)[ \t]+)))/gm;
+			var whole_list = /^(([ ]{0,3}([*\*]|[*\#])[ \t]+)[^\r]+?(~0|\n{2,}(?=\S)(?![ \t]*(?:[*\*]|[*\#])[ \t]+)))/gm;
 
 			if (g_list_level) {
 				text = text.replace(whole_list,function(wholeMatch,m1,m2) {
@@ -915,14 +896,12 @@ WYKIWYG.converter = function() {
 					return result;
 				});
 			} else {
-				//whole_list = /(\n|^\n?)(([ ]+([*\*]|[*\#]|\d\.)[ \t]+)[^\r]+?(~0|\n{2,}(?=\S)(?![ \t]*(?:[*\*]|[*\#]|\d\.)[ \t]+)))/g;
-				//whole_list = /(\n|^\n?)(([ ]+([*#]|\d\.)[ \t]+)[^\r]+?(~0|\n{2,}(?=\S)(?![ \t]*(?:[*#]|\d\.)[ \t]+)))/g;
-				whole_list = /(\n?)(([ ]+([*#]|\d\.)[ \t]+)[^\r]+?(~0|\n+)(?![ \t]+([*#]|\d\.)))/g;
+				whole_list = /(\n|^\n?)(([ ]{0,3}([*\*]|[*\#])[ \t]+)[^\r]+?(~0|\n{2,}(?=\S)(?![ \t]*(?:[*\*]|[*\#])[ \t]+)))/g;
 				text = text.replace(whole_list,function(wholeMatch,m1,m2,m3) {
 					var runup = m1;
 					var list = m2;
 
-					var list_type = (m3.search(/[*]/g)>-1) ? "ul" : "ol";
+					var list_type = (m3.search(/[*\*]/g)>-1) ? "ul" : "ol";
 					// Turn double returns into triple returns, so that we can make a
 					// paragraph for the last item in a list, if necessary:
 					var list = list.replace(/\n{2,}/g,"\n\n\n");;
@@ -971,8 +950,7 @@ WYKIWYG.converter = function() {
 			//  add sentinel to emulate \z
 			list_str += "~0";
 
-			//list_str = list_str.replace(/(\n)?(^[ \t]*)([*\*]|[*\#])[ \t]+([^\r]+?(\n{1,2}))(?=\n*(~0|\2([*\*]|[*\#])[ \t]+))/gm,
-			list_str = list_str.replace(/(\n)?(^[ \t]*)([*#]|\d\.)[ \t]+([^\r]+?(\n{1,2}))(?=\n*(~0|\2([*#]|\d\.)[ \t]+))/gm,
+			list_str = list_str.replace(/(\n)?(^[ \t]*)([*\*]|[*\#])[ \t]+([^\r]+?(\n{1,2}))(?=\n*(~0|\2([*\*]|[*\#])[ \t]+))/gm,
 				function(wholeMatch,m1,m2,m3,m4){
 					var item = m4;
 					var leading_line = m1;
@@ -1667,8 +1645,6 @@ WYKIWYG.converter = function() {
 		// contorted like /[ \t]*\n+/ .
 		text = text.replace(/^[ \t]+$/mg, "");
 
-		text = _DoMath(text);
-
 		text = _stripCodeBlocks(text);
 
 		text = _DoHtmlCodeBlocks(text);
@@ -1758,11 +1734,7 @@ WYKIWYG.editor = function() {
 		this.i.frameBorder = 0;
 		this.i.style.width = '100%'; //(obj.width || (this.t.offsetWidth || '500') - 8); 
 		//this.i.height = (obj.height || (this.t.offsetHeight || '250') - 8);
-		if (obj.footer) {
-			this.i.height = (obj.height || ((this.t.rows * parseInt($(this.t).css("font-size"))) || '250') - 8);
-		} else {
-			this.i.height = (obj.height || ((this.t.rows * parseInt($(this.t).css("font-size"))) || '250') + 50); // Add extra to account for footer height
-		}
+		this.i.height = (obj.height || ((this.t.rows * parseInt(this.t.getStyle("font-size"))) || '250') - 8);
 		this.ie = T$$$();
 		h.className = obj.rowclass || 'wykiwyg-header';
 		p.className = obj.cssclass || 'wykiwyg';
@@ -2068,34 +2040,19 @@ wykiwygs = [];
 window.addEvent('domready', function(){
 	$$('.wiki-toolbar-content').each(function(textarea) {
 		var id = $(textarea).getProperty('id');
-
-		var controls = [
-			'bold','italic','underline','strikethrough','|',
-			'subscript','superscript','|',
-			'orderedlist','unorderedlist','|',
-			'outdent','indent','|',
-			'unformat','|',
-			'style','|',
-			'hr','link','unlink'
-		];
-		if ($(this).hasClass('minimal')) {
-			controls = [
-				'bold','italic','underline','strikethrough','|',
-				'subscript','superscript','|',
-				'unformat','|',
-				'link','unlink'
-			];
-		}
-
-		var footer = true;
-		if ($(this).hasClass('no-footer')) {
-			footer = false;
-		}
-
+		
 		var edtr = new WYKIWYG.editor.edit('editor' + id,{
 			id: id,
-			controls: controls,
-			footer: footer,
+			controls: [
+						'bold','italic','underline','strikethrough','|',
+						'subscript','superscript','|',
+						'orderedlist','unorderedlist','|',
+						'outdent','indent','|',
+						'unformat','|',
+						'style','|',
+						'hr','link','unlink'
+					],
+			footer: true,
 			toggle: true,
 			resize: true,
 			xhtml: true,
